@@ -1,12 +1,12 @@
 import vstest
 #import gobject
 
-a = vstest.FoodElement ()
+a = vstest.Element ()
 a.say ("world")
 print ("--")
 a.say ("cruel world")
 print ("--")
 
 # Creating a 2nd element make it segfault
-#b=vstest.FoodElement ()
-#b.say ("salsa")
+b=vstest.Element ()
+b.say ("salsa")
